@@ -31,7 +31,7 @@
 #include <glib/gi18n-lib.h>
 
 #define SOURCE_ID_TEMPLATE    "grl-dleyna-%s"
-#define SOURCE_DESC_TEMPLATE  _("A source for browsing the DLNA server '%s'")
+#define SOURCE_DESC_TEMPLATE  _("A source for browsing the DLNA server “%s”")
 
 #define MEDIA_ID_PREFIX "dleyna:"
 #define MEDIA_ID_PREFIX_LENGTH 7
@@ -377,7 +377,7 @@ grl_dleyna_source_store_upload_update_cb (GrlDleynaSource      *self,
 
   if (!g_str_equal (upload_status, "COMPLETED")) {
     error = g_error_new (GRL_CORE_ERROR, GRL_CORE_ERROR_STORE_FAILED,
-                          _("Upload failed, '%s', transferred %lu of %lu bytes"),
+                          _("Upload failed, “%s”, transferred %lu of %lu bytes"),
                           upload_status,
                           (long unsigned int) length,
                           (long unsigned int) total);
