@@ -107,10 +107,16 @@ GRL_LOG_DOMAIN_STATIC(magnatune_log_domain);
 
 /* --- URLs --- */
 
-#define URL_GET_DB    "http://he3.magnatune.com/info/sqlite_normalized.db"
-#define URL_GET_CRC   "http://magnatune.com/info/changed.txt"
+#define URL_GET_DB     "http://he3.magnatune.com/info/sqlite_normalized.db"
+#define URL_GET_CRC    "http://magnatune.com/info/changed.txt"
 
-#define URL_SONG_PLAY "http://he3.magnatune.com/all"
+#define URL_SONG_PLAY  "http://he3.magnatune.com/all"
+#define URL_SONG_COVER "http://he3.magnatune.com/music"
+
+/* --- Cover Art --- */
+
+#define URL_SONG_COVER_FORMAT URL_SONG_COVER "/%s/%s/cover_%d.jpg"
+static gint cover_art_sizes[] = { 50, 75, 100, 160, 200, 300, 600, 1400 };
 
 /* --- Other --- */
 
@@ -206,7 +212,18 @@ grl_magnatune_plugin_init(GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER(grl_magnatune_plugin_init, NULL, SOURCE_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   MAGNATUNE_PLUGIN_ID,
+                   "Magnatune",
+                   "A plugin for searching music",
+                   "Victor Toso",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_magnatune_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Magnatune GObject ================= */
 
@@ -226,7 +243,7 @@ grl_magnatune_source_new(void)
                         "source-id", SOURCE_ID,
                         "source-name", SOURCE_NAME,
                         "source-desc", SOURCE_DESC,
-                        "supported-media", GRL_MEDIA_TYPE_AUDIO,
+                        "supported-media", GRL_SUPPORTED_MEDIA_AUDIO,
                         "source-tags", tags,
                         NULL);
 
@@ -334,7 +351,7 @@ magnatune_get_crc_done(GObject *source_object,
   gchar *new_crc_path = NULL;
   gchar *content = NULL;
   gsize length = 0;
-  gboolean ret = FALSE; 
+  gboolean ret = FALSE;
   GError *err = NULL;
 
   GRL_DEBUG("magnatune_get_crc_done");
@@ -369,7 +386,7 @@ static void
 magnatune_get_crc_async(void)
 {
   GrlNetWc *wc = NULL;
-  
+
   GRL_DEBUG("magnatune_get_crc_async");
 
   wc = grl_net_wc_new();
@@ -438,7 +455,7 @@ magnatune_get_db_done(GObject *source_object,
     if (ret == FALSE) {
       err = g_error_new(GRL_CORE_ERROR,
                         GRL_CORE_ERROR_MEDIA_NOT_FOUND,
-                        _("Failed to save database from magnatune - '%s'"),
+                        _("Failed to save database from magnatune: “%s”"),
                         err_fn->message);
       g_error_free(err_fn);
 
@@ -494,7 +511,7 @@ magnatune_check_update_done(GObject *source_object,
   gchar *new_crc = NULL;
   gchar *old_crc = NULL;
   gsize length = 0;
-  gboolean ret = FALSE; 
+  gboolean ret = FALSE;
   GError *err = NULL;
 
   ret = grl_net_wc_request_finish(GRL_NET_WC(source_object),
@@ -581,6 +598,12 @@ magnatune_check_update(void)
   g_free(new_db_path);
 }
 
+static void
+add_cover (gpointer url_to_cover, gpointer media)
+{
+  grl_media_add_thumbnail((GrlMedia *) media, url_to_cover);
+}
+
 
 static GrlMedia *
 build_media(gint track_id,
@@ -589,22 +612,22 @@ build_media(gint track_id,
             const gchar *track_name,
             gint track_number,
             gint duration,
-            const gchar *url_to_mp3)
+            const gchar *url_to_mp3,
+            GPtrArray *url_to_covers)
 {
   GrlMedia *media = NULL;
-  GrlMediaAudio *audio = NULL;
   gchar *str_track_id = NULL;
 
   media = grl_media_audio_new();
-  audio = GRL_MEDIA_AUDIO(media);
-  grl_media_audio_set_track_number(audio, track_number);
-  grl_media_audio_set_artist(audio, artist_name);
-  grl_media_audio_set_album(audio, album_name);
-
+  grl_media_set_track_number(media, track_number);
+  grl_media_set_artist(media, artist_name);
+  grl_media_set_album(media, album_name);
   grl_media_set_url(media, url_to_mp3);
   grl_media_set_duration(media, duration);
   grl_media_set_title(media, track_name);
 
+  g_ptr_array_foreach(url_to_covers, add_cover, media);
+
   str_track_id = g_strdup_printf("%d", track_id);
   grl_media_set_id(media, str_track_id);
   g_free(str_track_id);
@@ -617,6 +640,7 @@ build_media_track_from_stmt(sqlite3_stmt *sql_stmt)
 {
   GrlMedia *media = NULL;
 
+  gint i;
   gint track_id;
   gint duration;
   gint track_number;
@@ -626,6 +650,9 @@ build_media_track_from_stmt(sqlite3_stmt *sql_stmt)
   const gchar *raw_url;
   gchar *encoded_url;
   gchar *url_to_mp3;
+  gchar *encoded_artist;
+  gchar *encoded_album;
+  GPtrArray *url_to_covers;
 
   track_id = (guint) sqlite3_column_int(sql_stmt, MAGNATUNE_TRACK_ID);
   artist_name = (gchar *) sqlite3_column_text(sql_stmt, MAGNATUNE_ARTIST_NAME);
@@ -637,11 +664,24 @@ build_media_track_from_stmt(sqlite3_stmt *sql_stmt)
 
   encoded_url = g_uri_escape_string(raw_url, "", FALSE);
   url_to_mp3 = g_strdup_printf("%s/%s", URL_SONG_PLAY, encoded_url);
+
+  encoded_artist = g_uri_escape_string(artist_name, "", FALSE);
+  encoded_album = g_uri_escape_string(album_name, "", FALSE);
+  url_to_covers = g_ptr_array_new();
+  for (i = 0; i < G_N_ELEMENTS(cover_art_sizes); i++) {
+    gchar *cover = g_strdup_printf(URL_SONG_COVER_FORMAT, encoded_artist,
+                                   encoded_album, cover_art_sizes[i]);
+    g_ptr_array_add(url_to_covers, cover);
+  }
+
   media = build_media(track_id, artist_name, album_name, track_name,
-                      track_number, duration, url_to_mp3);
+                      track_number, duration, url_to_mp3, url_to_covers);
 
   g_free(encoded_url);
   g_free(url_to_mp3);
+  g_free(encoded_artist);
+  g_free(encoded_album);
+  g_ptr_array_free(url_to_covers, TRUE);
 
   return media;
 }
@@ -654,7 +694,7 @@ build_media_id_name_from_stmt(sqlite3_stmt *sql_stmt)
   gchar *id = NULL;
   const gchar *media_name = NULL;
 
-  media = grl_media_box_new();
+  media = grl_media_container_new();
   media_id = (guint) sqlite3_column_int(sql_stmt, 0);
   media_name = (gchar *) sqlite3_column_text(sql_stmt, 1);
   id = g_strdup_printf("%d", media_id);
@@ -665,7 +705,7 @@ build_media_id_name_from_stmt(sqlite3_stmt *sql_stmt)
   return media;
 }
 
-static GList* 
+static GList*
 magnatune_sqlite_execute(OperationSpec *os,
                          gchar *sql,
                          MagnatuneBuildMediaFn build_media_fn,
@@ -691,7 +731,7 @@ magnatune_sqlite_execute(OperationSpec *os,
     goto end_sqlite_execute;
   }
 
-  while ((ret = sqlite3_step(sql_stmt)) == SQLITE_BUSY); 
+  while ((ret = sqlite3_step(sql_stmt)) == SQLITE_BUSY);
 
   while (ret == SQLITE_ROW) {
     media = build_media_fn(sql_stmt);
@@ -738,7 +778,7 @@ magnatune_browse_root(OperationSpec *os)
 
   num = (os->count > MAGNATUNE_NUM_CAT) ? MAGNATUNE_NUM_CAT: os->count;
 
-  media = grl_media_box_new();
+  media = grl_media_container_new();
   grl_media_set_title(media, MAGNATUNE_ROOT_ARTIST);
   id = g_strdup_printf("root-%d", MAGNATUNE_ARTIST_CAT);
   grl_media_set_id(media, id);
@@ -749,7 +789,7 @@ magnatune_browse_root(OperationSpec *os)
   if (num == 0)
     return;
 
-  media = grl_media_box_new();
+  media = grl_media_container_new();
   grl_media_set_title(media, MAGNATUNE_ROOT_ALBUM);
   id = g_strdup_printf("root-%d", MAGNATUNE_ALBUM_CAT);
   grl_media_set_id(media, id);
@@ -760,7 +800,7 @@ magnatune_browse_root(OperationSpec *os)
   if (num == 0)
     return;
 
-  media = grl_media_box_new();
+  media = grl_media_container_new();
   grl_media_set_title(media, MAGNATUNE_ROOT_GENRE);
   id = g_strdup_printf("root-%d", MAGNATUNE_GENRE_CAT);
   grl_media_set_id(media, id);
@@ -774,10 +814,9 @@ magnatune_execute_browse(OperationSpec *os)
 {
   MagnatuneBuildMediaFn *build_fn;
   GrlMedia *media = NULL;
-  const gchar *container_id = NULL;
-  gchar *sql = NULL;
+  const gchar *container_id = NULL;  gchar *sql = NULL;
   gchar **touple = NULL;
-  gchar *box_id = NULL;
+  gchar *new_container_id = NULL;
   gchar *category_str_id = NULL;
   gint id = 0;
   gint num_medias = 0;
@@ -849,11 +888,11 @@ magnatune_execute_browse(OperationSpec *os)
   num_medias = g_list_length(list_medias) - 1;;
   for (iter = list_medias; iter; iter = iter->next) {
     media = iter->data;
-    box_id = g_strdup_printf("%s-%s",
+    new_container_id = g_strdup_printf("%s-%s",
                              category_str_id,
                              grl_media_get_id(media));
-    grl_media_set_id(media, box_id);
-    g_free(box_id);
+    grl_media_set_id(media, new_container_id);
+    g_free(new_container_id);
 
     os->callback(os->source,
                  os->operation_id,
